Captricity requires an application token to use the API. Get the token from https://shreddr.captricity.com/.
The functions looks for CaptricityToken in the environment. If it doesn't find it or if change is forced,
it looks for arguments passed in the function. If it fails to find that, it asks for input.
Usage
set_token(app_token = NULL, force = FALSE)
Arguments
app_token
Application token. Get these from https://shreddr.captricity.com/developer/.
force
Force change the CaptricityToken stored in the environment