Rdocumentation
powered by
Learn R Programming
captr (version 0.1.4)
get_template_id: Set Template ID
Description
To digitize documents, create a template using the Captricity Web UI at
https://shreddr.captricity.com/job/
The template tells Captricity which data to get from where in the document. Get the template id of the template
Usage
get_template_id()
Arguments
References
https://shreddr.captricity.com/developer/
Examples
Run this code
get_template_id()
Run the code above in your browser using
DataLab